@@ -1,5 +1,6 @@
 import threading
 from time import time
+from typing import Callable
 
 from api_analytics.core import log_request
 from django import conf
@@ -8,13 +9,13 @@ from django.http.response import HttpResponse
 
 
 class Analytics:
-    def __init__(self, get_response):
+    def __init__(self, get_response: Callable[[WSGIRequest], HttpResponse]) -> None:
         self.get_response = get_response
         self.api_key = getattr(conf.settings, "ANALYTICS_API_KEY", None)
 
-    def __call__(self, request: WSGIRequest):
+    def __call__(self, request: WSGIRequest) -> HttpResponse:
         start = time()
-        response: HttpResponse = self.get_response(request)
+        response = self.get_response(request)
         elapsed = time() - start
 
         json = {
@@ -25,9 +26,8 @@ class Analytics:
             'method': request.method,
             'status': response.status_code,
             'response_time': int(elapsed * 1000),
-            'framework': 'Flask'
+            'framework': 9
         }
 
         threading.Thread(target=log_request, args=(json,)).start()
-
         return response
\ No newline at end of file
