@@ -17,7 +17,7 @@ class Analytics(BaseHTTPMiddleware):
 
     async def dispatch(self, request: Request, call_next: RequestResponseEndpoint) -> Response:
         start = time()
-        response: Response = await call_next(request)
+        response = await call_next(request)
         elapsed = time() - start
         
         json = {
