@@ -18,9 +18,9 @@ class Analytics(BaseHTTPMiddleware):
         super().__init__()
         self.api_key = api_key
 
-    def dispatch(self, request: Request, call_next: Callable):
+    def dispatch(self, request: Request, call_next: Callable[[Request], Response]):
         start = time()
-        response: Response = call_next(request)
+        response = call_next(request)
         elapsed = time() - start
 
         json = {
